@@ -26,7 +26,7 @@ fn main() {
     let geohelmert_macro_text = "pipeline: {
             steps: [
                 cart: {ellps: ^left},
-                helmert: {dx: ^dx, dy: ^dy, dz: ^dz},
+                helmert: {x: ^x, y: ^y, z: ^z},
                 cart: {inv: true, ellps: ^right}
             ]
         }";
@@ -43,20 +43,20 @@ fn main() {
 
     // Now let's see whether it works - instantiate the macro, using the same
     // parameters as used in example 00.
-    let ed50_wgs84 =
-        match ctx.operator("geohelmert: {left: intl, right: GRS80, dx: -87, dy: -96, dz: -120}") {
-            Err(e) => return println!("Awful error: {}", e),
-            Ok(op) => op,
-        };
+    if let Some(ed50_wgs84) =
+        ctx.operation("geohelmert: {left: intl, right: GRS80, x: -87, y: -96, z: -120}")
+    {
+        // Now do the same transformation as in example 00
+        ctx.inv(ed50_wgs84, &mut data);
 
-    // Now do the same transformation as in example 00
-    ctx.inv(ed50_wgs84, &mut data);
-
-    // geo_all(data) transforms all elements in data from the internal GIS
-    // format (lon/lat in radians) to lat/lon in degrees.
-    C::geo_all(&mut data);
-    println!("ed50:");
-    for coord in data {
-        println!("    {:?}", coord);
+        // geo_all(data) transforms all elements in data from the internal GIS
+        // format (lon/lat in radians) to lat/lon in degrees.
+        C::geo_all(&mut data);
+        println!("ed50:");
+        for coord in data {
+            println!("    {:?}", coord);
+        }
+    } else {
+        println!("{}", ctx.report());
     }
 }
