@@ -13,10 +13,10 @@ pub struct Pipeline {
 }
 
 impl Pipeline {
-    pub fn new(args: &mut OperatorArgs, ctx: &mut Context) -> Result<Pipeline, String> {
+    pub fn new(args: &mut OperatorArgs, ctx: &mut Context) -> Result<Pipeline, &'static str> {
         let inverted = args.flag("inv");
         let mut steps = Vec::new();
-        let n = args.numeric_value("Pipeline", "_nsteps", 0.0)? as usize;
+        let n = args.numeric_value("_nsteps", 0.0)? as usize;
 
         for i in 0..n {
             // Each step is represented as args[_step_0] = YAML step definition.
@@ -26,8 +26,11 @@ impl Pipeline {
 
             // We need a recursive copy of "all globals so far"
             let mut oa = args.spawn(step_args);
-            let op = operator_factory(&mut oa, ctx, 0)?;
-            steps.push(op);
+            if let Some(op) = operator_factory(&mut oa, ctx, 0) {
+                steps.push(op);
+            } else {
+                return Err("Bad step");
+            }
         }
 
         let args = args.clone();
@@ -43,6 +46,9 @@ impl Pipeline {
 impl OperatorCore for Pipeline {
     fn fwd(&self, ctx: &mut Context, operands: &mut [CoordinateTuple]) -> bool {
         for step in &self.steps {
+            if step.is_noop() {
+                continue;
+            }
             if !step.operate(ctx, operands, fwd) {
                 return false;
             }
@@ -52,6 +58,9 @@ impl OperatorCore for Pipeline {
 
     fn inv(&self, ctx: &mut Context, operands: &mut [CoordinateTuple]) -> bool {
         for step in self.steps.iter().rev() {
+            if step.is_noop() {
+                continue;
+            }
             if !step.operate(ctx, operands, inv) {
                 return false;
             }
@@ -93,7 +102,7 @@ mod tests {
             ],
             steps: [
                 cart: {ellps: intl},
-                helmert: {dx: -87, dy: -96, dz: -120},
+                helmert: {x: -87, y: -96, z: -120},
                 cart: {inv: true, ellps: GRS80}
             ]
         }";
@@ -120,9 +129,9 @@ mod tests {
         // Check that definition argument introspection works
         assert_eq!(op.args(0).used["ellps"], "intl");
 
-        assert_eq!(op.args(1).used["dx"], "-87");
-        assert_eq!(op.args(1).used["dy"], "-96");
-        assert_eq!(op.args(1).used["dz"], "-120");
+        assert_eq!(op.args(1).used["x"], "-87");
+        assert_eq!(op.args(1).used["y"], "-96");
+        assert_eq!(op.args(1).used["z"], "-120");
 
         // Note: It's superfluous to give the arg "ellps: GRS80", so it is not registered as "used"
         assert_eq!(op.args(2).used["inv"], "true");
